@@ -71,7 +71,7 @@ def attach_to(device, changed_callback):
     assert changed_callback
 
     if not hasattr(device, 'status') or device.status is None:
-        if device.kind is None:
+        if not device.isDevice:
             device.status = ReceiverStatus(device, changed_callback)
         else:
             device.status = DeviceStatus(device, changed_callback)
@@ -116,8 +116,6 @@ class ReceiverStatus(dict):
             }
         )
 
-    __unicode__ = __str__
-
     def changed(self, alert=ALERT.NOTIFICATION, reason=None):
         # self.updated = _timestamp()
         self._changed_callback(self._receiver, alert=alert, reason=reason)
